@@ -7,7 +7,7 @@
   packageStartupMessage(
 
   crayon::cyan("\n
-* vignettes (or README)
+# vignettes (or README)
 
     vignettes (or README) URL:  https://CRAN.R-project.org/package=BayesianFROC
 
@@ -16,35 +16,37 @@
     To see .html vignettes with compiled TeX scripts,
     we need internet environment.
 
-    * R script for vignettes (internet environment required for TeX)
+    # R script for vignettes (internet environment required for TeX)
 
     vignette(package = \"BayesianFROC\",topic = \"Very_Very_Very_Brief_description\")
 
 
 
-    * Also run;
+    # Also run;
 
          explanation_about_package_BayesianFROC()
 
-* Demos
+# Demos
 
 
         demo(demo_MRMC, package=\"BayesianFROC\");
         demo(demo_srsc, package=\"BayesianFROC\");
         demo(demo_stan, package=\"BayesianFROC\");
         demo(demo_drawcurves_srsc, package=\"BayesianFROC\");
+        demo(demo_ppp, package=\"BayesianFROC\");
+
         demo_Bayesian_FROC();
         demo_Bayesian_FROC_without_pause();
 
-* Examples
-          * Example: A Single reader and A Single Modality
+# Examples
+          # Example: A Single reader and A Single Modality
 
                fit <- fit_Bayesian_FROC( ite  = 1111,
                                       summary = TRUE,
                                           cha = 1,
                                      dataList = dataList.Chakra.1.with.explantation )
 
-         * Example: Mutltiple reader and Mutltiple Modality
+         # Example: Mutltiple reader and Mutltiple Modality
 
                fit <- fit_Bayesian_FROC( ite  = 1111,
                                       summary = TRUE,
@@ -52,14 +54,14 @@
                                      dataList = dd )
 
 
-         * Example: SBC for a single reader and a single modality via rstan::sbc
+         # Example: SBC for a single reader and a single modality via rstan::sbc
 
                 fit <- Simulation_Based_Calibration_single_reader_single_modality_via_rstan_sbc()
 
 
 
 
-         * Example: Posterior Predictive P value of chi square goodness of fit
+         # Example: Posterior Predictive P value of chi square goodness of fit
 
 
                  p.value <- ppp(fit)
@@ -68,7 +70,7 @@
 
 
 
-*  Shiny based  Graphical User Interface for fitting and estimates and drawing curve;
+#  Shiny based  Graphical User Interface for fitting and estimates and drawing curve;
 
 
 
@@ -76,23 +78,23 @@
 
  ", crayon::bgWhite$red$bold$underline$italic("             fit_GUI_Shiny_MRMC()                  "),"
 
-* It will took a lot of time to run the codes for the first time, since stan files will be compiled.
+# It will took a lot of time to run the codes for the first time, since stan files will be compiled.
 
 
-* Reference: (pre-print, manuscript)
+# Reference: (pre-print, manuscript)
              Bayesian Models for Free-response Receiver Operating Characteristic Analysis
 
 
-* For reviewers of my manuscript, execute the following code
+# For reviewers of my manuscript, execute the following code
   to check the results in my manuscript.
 
         demo(demo_for_reviewers_of_my_manuscript, package=\"BayesianFROC\");
 
 ",
- crayon::cyan$bold$underline$italic("* Ver."),
+ crayon::cyan$bold$underline$italic("# Ver."),
   crayon::red$bold$underline$italic("0."),
    crayon::bgBlack$white$bold$underline$italic(" 2."),
-   crayon::bgBlack$white$bold$underline$italic("1")
+   crayon::bgBlack$white$bold$underline$italic("2")
    )
  # ,
  # "                 ",
@@ -119,6 +121,6 @@
 
 .onLoad <- function(libname, pkgname) {
 
-  # packageStartupMessage("\n* The package \"BayesianFROC\" is loaded. \n")
+  # packageStartupMessage("\n# The package \"BayesianFROC\" is loaded. \n")
 
   }
